<?php
/**
 * @package Intrackt-ArtPlacer
 */
/*
Plugin Name: Intrackt ArtPlacer
Plugin URI: http://Intrackt.com/offers-artplacer/
Description: Support export of selected products to ArtPlacer
Version: 1.0.0
Author: Intrackt
Author URI: https://Intrackt.com
License: GPLv2 or later
Text Domain: Intrackt
*/

/*
Copyright 2020 Intrackt
https://intrackt.com/plugins-artplacer/#license
*/

/*
 * Define useful constants
 */
define( 'INTRACKT_PLUGIN_NAME_ARTPLACER', 'ArtPlacer' );
define( 'INTRACKT_ARTPLACER_VERSION', '1.0.0' );
define( 'INTRACKT_ARTPLACER_MINIMUM_WP_VERSION', '4.8.1' );
define( 'INTRACKT_ARTPLACER_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
define( 'INTRACKT_ARTPLACER_TESTMODE', false );

/*
 * common for all plugins
 */
{
    /*
     * Common test to bail out if not executed from with WP
     */
    if ( !function_exists( 'add_action' ) ) {
        echo 'Hi there!  I\'m just a plugin, not much I can do when called directly.';
        exit;
    }

    /*
     * load the source for any required classes or files
     */
    require_once( INTRACKT_ARTPLACER_PLUGIN_DIR . 'class.Intrackt-ArtPlacer-Manager.php' );
    require_once( INTRACKT_ARTPLACER_PLUGIN_DIR . 'class.Intrackt-ArtPlacer-Common.php' );

    /*
     * add links to the plugin on the plugin page
     */
    add_filter('plugin_action_links_'.plugin_basename(__FILE__),array('Intrackt\ArtPlacer\Manager','actionLinksLeft'));
    add_filter('plugin_row_meta',array('Intrackt\ArtPlacer\Manager','actionLinksRight'),10,2);

    /*
     * activate the Manager singleton
     */
    add_action( 'init', array( 'Intrackt\ArtPlacer\Manager', 'init' ) );

    /*
     * set the location of the code that activates the ArtPlacer plugin
     */
    register_activation_hook( __FILE__, array( '\Intrackt\ArtPlacer\Manager', 'activate' ) );

    /*
     * set up the process to automatically go to the main ArtPlacer page as the activation welcome page
     */
    add_action( 'admin_init', array( '\Intrackt\ArtPlacer\Manager', 'welcome' ) );

    /*
     * Add the logic to create the menu if ArtPlacer is activated
     */
    add_action('admin_menu', array( '\Intrackt\ArtPlacer\Manager', 'menuCreate' ));

    /*
     * set the location of the code that deactivates the ArtPlacer plugin
     */
    register_deactivation_hook( __FILE__, array( '\Intrackt\ArtPlacer\Manager', 'deactivate' ) );
    
    /*
     * add filter to add content to the intrackt common menu page
     */
    add_filter('intract_commonpage_body', array( '\Intrackt\ArtPlacer\Common', 'displayBody' ));

}

/*
 * For this plugin
 */
{
    /*
     * load the source for any required classes or files
     */
    require_once( INTRACKT_ARTPLACER_PLUGIN_DIR . 'class.Intrackt-ArtPlacer-Actions.php' );

    /*
     * add include of widget javascript on bottom of storefront pages
     */
    add_action('wp_footer',array('\Intrackt\ArtPlacer\Actions','storeFooter'),20);
    
    /*
     * Add shortcodes
     */
    add_shortcode("artplacer",array('\Intrackt\ArtPlacer\Actions','artPlacer'));
    
}
