<?php
namespace Intrackt\ArtPlacer;

/*
 * load the source for any required classes or files
 */
require_once( INTRACKT_ARTPLACER_PLUGIN_DIR . 'class.Intrackt-ArtPlacer-PageLog.php' );
//require_once(\ABSPATH.'/wp-includes/pluggable.php');

/*
 * The Actions class will display any log messages generated by the ArtPlacer
 */
class Actions {

    /*
     * Have we instantiated the class-- this is a singleton and does not produce children
     */
	private static $initiated = false;
    
    /*
     * Init class
     */
	public static function init() {
		if ( ! self::$initiated ) {
    		self::$initiated = true;
		}
        
	}

    /* **********************************************************
     * add artplacer widget at bottom of storefront page
     */
    public static function storeFooter() {
        
        echo "<script src='//widget.artplacer.com/js/script.js'></script>";
                
    }
        
    /* **********************************************************
     * Support aartplacer shortcode
     */
    public static function artPlacer($atts) {
        
        /*
         * Get the attributes of the shortcode with defaults
         */
        $args = shortcode_atts(
            array(
                'gallery_number'=>'',
                'gallery_type'=>'',
                'space_number'=>'',
                'catalog'=>''
                )
            ,apply_filters('intrackt_artplacer_shortcode_atts',$atts));
        
        /*
         * validate all parameters
         */
        {
            /*
             * start assuming no errors
             */
            $errors=array();

            /*
             * galleryNumber
             */
            $galleryNumber=trim($args['gallery_number']);
            if ((!is_numeric($galleryNumber))||(!is_int($galleryNumber*1))||($galleryNumber<1))
                $errors[]="<p>gallery_number must be a positive whole number.</p>";

            /*
             * galleryType
             */
            $galleryType=trim($args['gallery_type']);
            if ((!is_numeric($galleryType))||(!is_int($galleryType*1))||($galleryType<1))
                $errors[]="<p>gallery_type must be a positive whole number.</p>";

            /*
             * spaceNumber
             */
            $spaceNumber=trim($args['space_number']);
            if ((!is_numeric($spaceNumber))||(!is_int($spaceNumber*1))||($spaceNumber<1))
                $errors[]="<p>space_number must be a positive whole number.</p>";

            /*
             * catalog
             */
            $catalog=$args['catalog'];
            if (($catalog!='true')&&($catalog!='false'))
                $errors[]="<p>catalog is '{$catalog}'.  It must be 'true' or 'false'.</p>";
                
            /*
             * others ???
             */
            $errors=apply_filters('intrackt_artplacer_shortcode_errors',$errors,$args);
            
        }
        
        /*
         * if errors, report them
         */
        if (count($errors)>0) {
            
            /*
             * let others fiddle the valid attributes
             */
            $attributes=apply_filters('intrackt_artplacer_shortcode_definitionattributes',array(
                'gallery_number'=>'integer',
                'gallery_type'=>'integer',
                'space_number'=>'integer',
                'catalog'=>'true/false'
                 ));
            
            /*
             * and build actual shortcode attributes
             */
            foreach ($attributes as $name=>$value)
                $pairs[]="{$name}='{$value}'";

            /*
             * return errors
             */
            return apply_filters('intrackt_artplacer_shortcode_definition',"<p>Shortcode help:  [artplacer ".implode(' ',$pairs)."]</p>").
                implode(' ',$errors);
            
        /*
         * otherwise we are valid, so try to output widget
         */
        } else {
        
            /*
             * get post ID, but if no post, say so
             */
            $postId=apply_filters('intrackt_artplacer_shortcode_postid',get_the_ID(),$args);
            if ($postId===false)
                return "ArtPlacer: there is no current product selected.";
            
            /*
             * get product object, but exit if no current product
             */
            if (($product=wc_get_product($postId))===null)
                return "ArtPlacer: there is no current product selected.";
            
            /*
             * get image ID, but bail if missing
             */
            $imageId=$product->get_image_id();
            if (($imageId===null)||($imageId==''))
                return "Product does not have an image.";
            
            $artworkUrl=wp_get_attachment_url($imageId);
            
            $height=$product->get_height();
            
            /*
             * let others fiddle the valid attributes
             */
            $attributes=apply_filters('intrackt_artplacer_shortcode_widgetattributes',array(
                'gallery'=>$galleryNumber,
                'type'=>$galleryType,
                'artwork_url'=>$artworkUrl,
                'height'=>$height,
                'space'=>$spaceNumber,
                'resizable'=>'false',
                'text'=>'View In A Room',
                'catalog'=>$catalog,
                'default_style'=>'true'
                 ));
            
            /*
             * and build actual widget attributes
             */
            foreach ($attributes as $name=>$value)
                $pairs[]="{$name}='{$value}'";

            /*
             * output widget
             */
            //PageLog::updateTestLog("shortcode: <artplacer ".implode(' ',$pairs)."></artplacer>");
            return apply_filters('intrackt_artplacer_shortcode_widget',"<artplacer ".implode(' ',$pairs)."></artplacer>");
            
            }

    }
        
}
